.. _api_meshing_polymesh:

.. currentmodule:: microstructpy.meshing

microstructpy.meshing.PolyMesh
==============================

.. autoclass:: PolyMesh
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
